<?php
namespace Ep;

use Ep\Mail\Transport\AbstractTransportFactory;
use Twig_Environment;
use Laminas;
use Laminas\Form\FormElementManagerFactory;
use Laminas\ServiceManager\Factory\InvokableFactory;

/** @noinspection PhpUnnecessaryFullyQualifiedNameInspection */
/** @noinspection PhpUndefinedClassInspection */
/** @noinspection PhpUndefinedNamespaceInspection */
return [
    'dependencies' => [
        'aliases' => [
            'currency_converter' => Currency\Converter::class,
            'mail'               => Laminas\Mail\Transport\TransportInterface::class,
            'search'             => Solarium\Client::class,
            'twig'               => Twig_Environment::class,

            'app.access_control_headers' => Middleware\AccessControlHeaders::class,
            'app.base_url'               => Middleware\BaseUrl::class,
            'app.error_handler'          => Laminas\Stratigility\Middleware\ErrorHandler::class,
            'app.force_https'            => Middleware\ForceHttps::class,
            'app.force_www'              => Middleware\ForceWww::class,
            'app.middleware_bridge'      => Middleware\MiddlewareBridge::class,

            'EventManager'               => Laminas\EventManager\EventManager::class,
            'SharedEventManager'         => Laminas\EventManager\SharedEventManager::class,

            \Laminas\View\Renderer\RendererInterface::class => View\Renderer\TwigRenderer::class,
        ],

        'factories' => [
            Currency\Adapter\AdapterInterface::class      => Currency\Adapter\AbstractAdapterFactory::class,
            Currency\Converter::class                     => Currency\ConverterFactory::class,
            Solarium\Client::class                        => Search\ClientFactory::class,
            Twig_Environment::class                       => View\TwigFactory::class,
            Laminas\Db\Adapter\AdapterInterface::class       => Db\Adapter\AdapterServiceFactory::class,
            Laminas\Mail\Protocol\SmtpPluginManager::class   => Laminas\Mail\Protocol\SmtpPluginManagerFactory::class,
            Laminas\Mail\Transport\TransportInterface::class => Mail\Transport\AbstractTransportFactory::class,
            View\Renderer\TwigRenderer::class   => View\Renderer\TwigRendererFactory::class,

            Middleware\AccessControlHeaders::class => InvokableFactory::class,
            Middleware\BaseUrl::class              => InvokableFactory::class,
            Middleware\ForceHttps::class           => InvokableFactory::class,
            Middleware\ForceWww::class             => InvokableFactory::class,
            Middleware\MiddlewareBridge::class     => InvokableFactory::class,

            Laminas\EventManager\EventManager::class            => EventManager\EventManagerFactory::class,
            Laminas\EventManager\SharedEventManager::class      => InvokableFactory::class,
            Laminas\Stratigility\Middleware\ErrorHandler::class => Middleware\ErrorHandlerFactory::class,

            'app'                => Middleware\AppFactory::class,
            'app.logger'         => Log\LoggerAbstractServiceFactory::class,
            'app.mailer'         => AbstractTransportFactory::class,
            'FormElementManager' => FormElementManagerFactory::class,
        ],

        'shared' => [
            'EventManager' => false,
        ],
    ],
];
