<?php
namespace Ep\Mail\Transport;

use Interop\Container\ContainerInterface;
use Laminas\Mail\Protocol\SmtpPluginManager;
use Laminas\Mail\Transport\Factory;
use Laminas\Mail\Transport\Smtp;
use Laminas\Mail\Transport\TransportInterface;
use Laminas\ServiceManager\Factory\FactoryInterface;

/**
 * Stvara MailTransport definiran u konfiguraciji.
 *
 * @package Ep\Mail\Transport
 * @author Elektronika Perhoč <web@ep.hr>
 * @link http://gitlab.ep.local/ep-framework/core
 */
class AbstractTransportFactory implements FactoryInterface
{
    /**
     * Create an object
     *
     * @param  ContainerInterface $container
     * @param  string $requestedName
     * @param  null|array $options
     *
     * @return TransportInterface
     *
     * @throws \Psr\Container\ContainerExceptionInterface
     * @throws \Psr\Container\NotFoundExceptionInterface
     */
    public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
    {
        $config = $container->get('config')['mail'] ?? [];

        if (TransportInterface::class !== $requestedName) {
            if (!isset($config['transports'][$requestedName])) {
                throw new \RuntimeException(sprintf(
                    "Mail transport s imenom '%s' ne postoji u konfiguraciji.", $requestedName
                ));
            }

            $config = $config['transports'][$requestedName];
        }

        $transport = Factory::create($config);

        if ($transport instanceof Smtp) {
            $plugins = $container->get(SmtpPluginManager::class);
            $transport->setPluginManager($plugins);
        }

        return $transport;
    }
}
